==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Vse pisave</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uporabnik</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Priljubljene</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktivne</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kitajske</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Z enotnim razmikom</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 ni družina pisav. Če boste nadaljevali, bodo izbrisane vse pisave</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 je družina pisav. Če boste nadaljevali, bodo vklopljene vse pisave</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 je družina pisav. Če boste nadaljevali, bodo izklopljene vse pisave</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Omogoči</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Onemogoči</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Uporabi za vse izbrane družine pisav</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Okvarjena datoteka</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Nameščena je ista različica</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Sistemska pisava</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 pisav nameščenih</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 pisav nameščenih</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">Okvarjena datoteka</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ta pisava na bo na voljo programom</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Te pisave ne bodo na voljo programom</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Drugih %1 sistemskih pisav ni mogoče izbrisati</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Pisave &quot;%1&quot; ni mogoče izbrisati</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Drugih %1 sistemskih pisav in pisave &quot;%2&quot;, ki je v rabi, ni mogoče izbrisati</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Želite res izbrisati %1 pisav?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Brisanje pisav, počakajte...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Preverjanje pisav</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Nobena pisava ne bo namščena</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Izhod</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Nadaljevanje</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Osnovni podatki</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Slog</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Različica</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Polno ime</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps ime</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Blagovna znamka</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Upravitelj pisav</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Upravitelj pisav pomaga uproabniku namestiti in upravljati pisave.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Nalaganje pisav, počakajte...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Pisava, izvožena na namizje</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 pisav izvoženih na namizje</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Neuspel izvoz 1 pisave. Na disku ni dovolj prostora.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Neuspel izvoz %1 pisav. Na disku ni dovolj prostora.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Dodaj pisavo</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Omogoči</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Onemogoči</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Priljubljena</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nepriljubljena</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Izvozi</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>deaktivirano</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Pisave so bile eaktivirane</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 se uporablja, zato je ne morete onemogočiti</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Ne morete onemogočiti sistemskih pisav in pisav, ki so v rabi</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Ne morete onemogočiti sistemskih pisav</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Namesti pisavo</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Preverjanje</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Okvarjena datoteka</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Nameščeno</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Ni nameščeno</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Namesti pisavo</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Ni rezultatov iskanj</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Ni pisav</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Bljižnice prikaza</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Stran gor</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Stran dol</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Dodaj pisavo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Priljubljena</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nepriljubljena</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Podatki o pisavi</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Vnesite besedilo predogleda</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Vse pisave</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uporabnik</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Priljubljene</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktivne</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kitajske</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Z enotnim razmikom</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 ni družina pisav. Če boste nadaljevali, bodo izbrisane vse pisave</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 je družina pisav. Če boste nadaljevali, bodo vklopljene vse pisave</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 je družina pisav. Če boste nadaljevali, bodo izklopljene vse pisave</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Omogoči</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Onemogoči</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Uporabi za vse izbrane družine pisav</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Okvarjena datoteka</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Nameščena je ista različica</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Sistemska pisava</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 pisav nameščenih</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 pisav nameščenih</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Neuspešna namestitev %1 pisave. Na disku ni dovolj prostora.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Neuspešna namestitev %1 pisav. Na disku ni dovolj prostora.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Pisave</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Okvarjena datoteka</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ta pisava na bo na voljo programom</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Te pisave ne bodo na voljo programom</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Drugih %1 sistemskih pisav ni mogoče izbrisati</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Pisave &quot;%1&quot; ni mogoče izbrisati</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Drugih %1 sistemskih pisav in pisave &quot;%2&quot;, ki je v rabi, ni mogoče izbrisati</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Želite res izbrisati %1 pisav?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Brisanje pisav, počakajte...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Preverjanje pisav</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Nobena pisava ne bo namščena</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izhod</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nadaljevanje</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Naj vaše sanje ne bodo sanje</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Osnovni podatki</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Slog</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Različica</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Polno ime</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps ime</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Blagovna znamka</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Pravna oznaka</translation>
    </message>
    <message>
        <source>License Description</source>
        <translation>Opis licenčne pogojeve</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Upravitelj pisav</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Upravitelj pisav pomaga uproabniku namestiti in upravljati pisave.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Nalaganje pisav, počakajte...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Pisava, izvožena na namizje</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 pisav izvoženih na namizje</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Neuspel izvoz 1 pisave. Na disku ni dovolj prostora.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Neuspel izvoz %1 pisav. Na disku ni dovolj prostora.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Dodaj pisavo</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Omogoči</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Onemogoči</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Priljubljena</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nepriljubljena</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Izvozi</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>deaktivirano</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Pisave so bile eaktivirane</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 se uporablja, zato je ne morete onemogočiti</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Ne morete onemogočiti sistemskih pisav in pisav, ki so v rabi</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Ne morete onemogočiti sistemskih pisav</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Namesti pisavo</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Preverjanje</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Okvarjena datoteka</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Nameščeno</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Ni nameščeno</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Namesti pisavo</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Ni rezultatov iskanj</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Ni pisav</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Bljižnice prikaza</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Stran gor</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Stran dol</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Dodaj pisavo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Priljubljena</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nepriljubljena</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Podatki o pisavi</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Vnesite besedilo predogleda</translation>
    </message>
</context>
</TS>
